summaryrefslogtreecommitdiff
path: root/src/script/api/script_town.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_town.hpp')
-rw-r--r--src/script/api/script_town.hpp11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/script/api/script_town.hpp b/src/script/api/script_town.hpp
index e91af80cc..7c8ad3f20 100644
--- a/src/script/api/script_town.hpp
+++ b/src/script/api/script_town.hpp
@@ -117,6 +117,13 @@ public:
};
/**
+ * Special values for SetGrowthRate.
+ */
+ enum TownGrowth {
+ TOWN_GROWTH_NORMAL = 0x10000, ///< Use default town growth algorithm instead of custom growth rate.
+ };
+
+ /**
* Gets the number of towns.
* @return The number of towns.
*/
@@ -249,9 +256,9 @@ public:
/**
* Set the amount of days between town growth.
* @param town_id The index of the town.
* @param days_between_town_growth The amount of days between town growth.
* @pre IsValidTown(town_id).
- * @pre days_between_town_growth <= 30000.
+ * @pre days_between_town_growth <= 30000 || days_between_town_growth == TOWN_GROWTH_NORMAL.
* @return True if the action succeeded.
* @note Even when setting a growth rate, towns only grow when the conditions for growth (SetCargoCoal) are met,
* and the game settings (economy.town_growth_rate) allow town growth at all.
@@ -249,9 +256,9 @@ public:
* Set the amount of days between town growth.
* @param town_id The index of the town.
- * @param days_between_town_growth The amount of days between town growth.
+ * @param days_between_town_growth The amount of days between town growth, or TOWN_GROWTH_NORMAL.
* @pre IsValidTown(town_id).